==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkTecplotReader.java <==
// java wrapper for vtkTecplotReader object
//

package vtk;
import vtk.*;

public class vtkTecplotReader extends vtkMultiBlockDataSetAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetNumberOfVariables_2();
  public int GetNumberOfVariables()
    { return GetNumberOfVariables_2(); }

  private native void SetFileName_3(String id0);
  public void SetFileName(String id0)
    { SetFileName_3(id0); }

  private native String GetDataTitle_4();
  public String GetDataTitle()
    { return GetDataTitle_4(); }

  private native int GetNumberOfBlocks_5();
  public int GetNumberOfBlocks()
    { return GetNumberOfBlocks_5(); }

  private native String GetBlockName_6(int id0);
  public String GetBlockName(int id0)
    { return GetBlockName_6(id0); }

  private native int GetNumberOfDataAttributes_7();
  public int GetNumberOfDataAttributes()
    { return GetNumberOfDataAttributes_7(); }

  private native String GetDataAttributeName_8(int id0);
  public String GetDataAttributeName(int id0)
    { return GetDataAttributeName_8(id0); }

  private native int IsDataAttributeCellBased_9(String id0);
  public int IsDataAttributeCellBased(String id0)
    { return IsDataAttributeCellBased_9(id0); }

  private native int IsDataAttributeCellBased_10(int id0);
  public int IsDataAttributeCellBased(int id0)
    { return IsDataAttributeCellBased_10(id0); }

  private native int GetNumberOfDataArrays_11();
  public int GetNumberOfDataArrays()
    { return GetNumberOfDataArrays_11(); }

  private native String GetDataArrayName_12(int id0);
  public String GetDataArrayName(int id0)
    { return GetDataArrayName_12(id0); }

  private native int GetDataArrayStatus_13(String id0);
  public int GetDataArrayStatus(String id0)
    { return GetDataArrayStatus_13(id0); }

  private native void SetDataArrayStatus_14(String id0,int id1);
  public void SetDataArrayStatus(String id0,int id1)
    { SetDataArrayStatus_14(id0,id1); }

  public vtkTecplotReader() { super(); }

  public vtkTecplotReader(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-14-aarch64.pkg.tar.xz: vtk/vtkTecplotReader.java <==
// java wrapper for vtkTecplotReader object
//

package vtk;
import vtk.*;

public class vtkTecplotReader extends vtkMultiBlockDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetNumberOfVariables_2();
  public int GetNumberOfVariables()
    { return GetNumberOfVariables_2(); }

  private native void SetFileName_3(String id0);
  public void SetFileName(String id0)
    { SetFileName_3(id0); }

  private native String GetDataTitle_4();
  public String GetDataTitle()
    { return GetDataTitle_4(); }

  private native int GetNumberOfBlocks_5();
  public int GetNumberOfBlocks()
    { return GetNumberOfBlocks_5(); }

  private native String GetBlockName_6(int id0);
  public String GetBlockName(int id0)
    { return GetBlockName_6(id0); }

  private native int GetNumberOfDataAttributes_7();
  public int GetNumberOfDataAttributes()
    { return GetNumberOfDataAttributes_7(); }

  private native String GetDataAttributeName_8(int id0);
  public String GetDataAttributeName(int id0)
    { return GetDataAttributeName_8(id0); }

  private native int IsDataAttributeCellBased_9(String id0);
  public int IsDataAttributeCellBased(String id0)
    { return IsDataAttributeCellBased_9(id0); }

  private native int IsDataAttributeCellBased_10(int id0);
  public int IsDataAttributeCellBased(int id0)
    { return IsDataAttributeCellBased_10(id0); }

  private native int GetNumberOfDataArrays_11();
  public int GetNumberOfDataArrays()
    { return GetNumberOfDataArrays_11(); }

  private native String GetDataArrayName_12(int id0);
  public String GetDataArrayName(int id0)
    { return GetDataArrayName_12(id0); }

  private native int GetDataArrayStatus_13(String id0);
  public int GetDataArrayStatus(String id0)
    { return GetDataArrayStatus_13(id0); }

  private native void SetDataArrayStatus_14(String id0,int id1);
  public void SetDataArrayStatus(String id0,int id1)
    { SetDataArrayStatus_14(id0,id1); }

  public vtkTecplotReader() { super(); }

  public vtkTecplotReader(long id) { super(id); }
  public native long   VTKInit();

}
